==> zy-fetch-1.6.9.tgz: package/lib/fetch/nodeFetch.js <==
'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nodeFetch = require('node-fetch');

/**
 * set signal in request
 * @param input
 * @param init
 * @returns {Request|*}
 * @constructor
 */
function AbortRequest(input, init) {
  var request = new nodeFetch.Request(input, init);
  if (init && init.signal) {
    request.signal = init.signal;
  }
  return request;
}

AbortRequest.prototype = nodeFetch.Request.prototype;

/**
 * in node env, to abort fetch request
 */
function abortFetch(init, option) {
  var isRequest = init && init instanceof nodeFetch.Request;
  var signal = isRequest ? init.signal : option ? option.signal : undefined;
  if (signal) {
    var abortError = void 0;
    try {
      abortError = new DOMException('Aborted', 'AbortError');
    } catch (err) {
      var _DOMException = require('../util/domException');
      abortError = new _DOMException('Aborted', 'AbortError');
    }

    if (signal.aborted) {
      return _promise2.default.reject(abortError);
    }

    var cancellation = new _promise2.default(function (_, reject) {
      signal.addEventListener('abort', function () {
        return reject(abortError);
      }, { once: true });
    });
    return _promise2.default.race([cancellation, nodeFetch(init, option)]);
  }
  return nodeFetch(init, option);
}

if (global) {
  global.Response = nodeFetch.Response;
  global.Request = AbortRequest;
  global.Headers = nodeFetch.Headers;
}

module.exports = abortFetch;

==> zy-fetch-1.7.6.tgz: package/lib/fetch/nodeFetch.js <==
"use strict";

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.promise");

var nodeFetch = require('node-fetch');
/**
 * set signal in request
 * @param input
 * @param init
 * @returns {Request|*}
 * @constructor
 */


function AbortRequest(input, init) {
  var request = new nodeFetch.Request(input, init);

  if (init && init.signal) {
    request.signal = init.signal;
  }

  return request;
}

AbortRequest.prototype = nodeFetch.Request.prototype;
/**
 * in node env, to abort fetch request
 */

function abortFetch(init, option) {
  var isRequest = init && init instanceof nodeFetch.Request;
  var signal = isRequest ? init.signal : option ? option.signal : undefined;

  if (signal) {
    var abortError = void 0;

    try {
      abortError = new DOMException('Aborted', 'AbortError');
    } catch (err) {
      var _DOMException = require('../util/domException');

      abortError = new _DOMException('Aborted', 'AbortError');
    }

    if (signal.aborted) {
      return Promise.reject(abortError);
    }

    var cancellation = new Promise(function (_, reject) {
      signal.addEventListener('abort', function () {
        return reject(abortError);
      }, {
        once: true
      });
    });
    return Promise.race([cancellation, nodeFetch(init, option)]);
  }

  return nodeFetch(init, option);
}

if (global) {
  global.Response = nodeFetch.Response;
  global.Request = AbortRequest;
  global.Headers = nodeFetch.Headers;
}

module.exports = abortFetch;
